@@ -9,23 +9,23 @@ def get_all_tidstyv(db: Session):
     return db.query(models.Tidstyv).order_by(desc(models.Tidstyv.stolen)).all()
 
 
-def get_tidstyv_by_id(db: Session, user_id: str):
-    return db.query(models.Tidstyv).filter_by(user_id=user_id).first()
+def get_tidstyv_by_id(db: Session, user: str):
+    return db.query(models.Tidstyv).filter_by(user=user).first()
 
 
 def add_tidstyveri(db: Session, tidstyv: schemas.TidstyvIn):
-    res = db.query(models.Tidstyv).filter_by(user_id=tidstyv.user_id).first()
+    res = db.query(models.Tidstyv).filter_by(user=tidstyv.user).first()
     if res:
         res.stolen += tidstyv.stolen
     else:
-        db.add(models.Tidstyv(user_id=tidstyv.user_id, stolen=tidstyv.stolen))
+        db.add(models.Tidstyv(user=tidstyv.user, stolen=tidstyv.stolen))
     db.commit()
     # NOTE: There has to be a better way?
-    return db.query(models.Tidstyv).filter_by(user_id=tidstyv.user_id).first()
+    return db.query(models.Tidstyv).filter_by(user=tidstyv.user).first()
 
 
 def remove_tidstyveri(db: Session, tidstyv: schemas.TidstyvIn):
-    res = db.query(models.Tidstyv).filter_by(user_id=tidstyv.user_id).first()
+    res = db.query(models.Tidstyv).filter_by(user=tidstyv.user).first()
     if not res:
         return
     res.stolen -= tidstyv.stolen
@@ -36,7 +36,7 @@ def remove_tidstyveri(db: Session, tidstyv: schemas.TidstyvIn):
     return res
 
 
-def delete_tidstyv(db: Session, user_id: str):
-    res = db.query(models.Tidstyv).filter_by(user_id=user_id).delete()
+def delete_tidstyv(db: Session, user: str):
+    res = db.query(models.Tidstyv).filter_by(user=user).delete()
     db.commit()
     return res
