@@ -1,9 +1,12 @@
+import socket
+
+from fastapi import Request
 from fastapi.applications import FastAPI
 from fastapi.exceptions import HTTPException
-from sqlalchemy.exc import IntegrityError
-from fastapi import Request
 from fastapi.responses import JSONResponse
+from sqlalchemy.exc import IntegrityError
 from starlette.responses import PlainTextResponse
+from ..cache import cache, MockCache
 
 
 async def handle_integrity_error(request: Request, exc: IntegrityError):
@@ -13,8 +16,15 @@ async def handle_integrity_error(request: Request, exc: IntegrityError):
         raise exc
 
 
+async def handle_socket_gaierror(request: Request, exc: socket.gaierror):
+    global cache
+    cache = MockCache()
+    return PlainTextResponse("Invalid cache, try again.", status_code=500)
+
+
 HANDLERS = {
     IntegrityError: handle_integrity_error,
+    socket.gaierror: handle_socket_gaierror,
 }
 
 
