@@ -8,7 +8,7 @@ class Subreddit(Base):
 
     subreddit = Column(String, primary_key=True, index=True)
     is_text = Column(Boolean)
-    submitter = Column(String)
+    user = Column(String)
     submitted = Column(DateTime, default=None)
     aliases = relationship("SubredditAlias")
 
