@@ -9,6 +9,6 @@ class Skribbl(Base):
     __tablename__ = "Skribbl"
 
     word = Column(String, primary_key=True, index=True)
-    submitter = Column(String)
+    user = Column(String)
     submitted = Column(DateTime, default=datetime.utcnow)
     submittedReal = Column(Float, default=0.0)
