@@ -1,8 +1,8 @@
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 
 class GamingMomentsBase(BaseModel):
-    user_id: str
+    user: str
     count: int
 
 
