@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 
 class SubredditAliasBase(BaseModel):
@@ -19,7 +19,7 @@ class SubredditAliasOut(BaseModel):
 class SubredditBase(BaseModel):
     subreddit: str
     is_text: bool
-    submitter: str
+    user: str = Field(..., alias="user", title="user")
 
 
 class SubredditIn(SubredditBase):
