@@ -2,7 +2,7 @@ from pydantic import BaseModel
 
 
 class TidstyvBase(BaseModel):
-    user_id: str
+    user: str
     stolen: float
 
 
